@@ -1142,6 +1142,13 @@ def make_workflow_from_user_options():
 def cli_run():
     """Main entry point."""
 
+    from visualqc import __version__
+    print('\nvisualqc version {} for functional MRI'.format(__version__))
+    from datetime import datetime
+    init_time = datetime.now()
+    print('\tTime stamp : {}\n'.format(init_time.strftime('%Y-%m-%d %H:%M:%S')))
+
+
     wf = make_workflow_from_user_options()
     wf.run()
 
